@@ -101,6 +101,17 @@ if 'op_ff' not in globals():
 _bdd_dict = make_bdd_dict()
 
 
+
+__om_init_tmp = option_map.__init__
+def __om_init_new(self, str=None):
+    __om_init_tmp(self)
+    if str:
+        res = self.parse_options(str)
+        if res:
+            raise RuntimeError("failed to parse option at: '" + str +"'")
+option_map.__init__ = __om_init_new
+
+
 @_extend(twa, ta)
 class twa:
     def _repr_svg_(self, opt=None):
@@ -175,6 +186,13 @@ class twa:
                 f.write('\n')
         return a
 
+@_extend(twa_graph)
+class twa_graph:
+    def show_storage(self, opt=None):
+        ostr = ostringstream()
+        self.dump_storage_as_dot(ostr, opt)
+        from IPython.display import SVG
+        return SVG(_ostream_to_svg(ostr))
 
 @_extend(formula)
 class formula:
@@ -334,19 +352,6 @@ class formula:
 
 @_extend(atomic_prop_set)
 class atomic_prop_set:
-    def __repr__(self):
-        res = '{'
-        comma = ''
-        for ap in self:
-            res += comma
-            comma = ', '
-            res += '"' + ap.ap_name() + '"'
-        res += '}'
-        return res
-
-    def __str__(self):
-        return self.__repr__()
-
     def _repr_latex_(self):
         res = '$\{'
         comma = ''
@@ -681,7 +686,7 @@ def _postproc_translate_options(obj, default_type, *args):
     obj.set_level(optm_)
 
 
-def translate(formula, *args, dict=_bdd_dict):
+def translate(formula, *args, dict=_bdd_dict, xargs=None):
     """Translate a formula into an automaton.
 
     Keep in mind that 'Deterministic' expresses just a preference that
@@ -701,12 +706,22 @@ def translate(formula, *args, dict=_bdd_dict):
       'Colored' (only for parity acceptance)
 
     The default corresponds to 'tgba', 'small' and 'high'.
+
+    Additional options can be supplied using a `spot.option_map`, or a
+    string (that will be converted to `spot.option_map`), as the `xargs`
+    argument.  This is similar to the `-x` option of command-line tools;
+    so check out the spot-x(7) man page for details.
     """
-    a = translator(dict)
+    if type(xargs) is str:
+        xargs = option_map(xargs)
+    a = translator(dict, xargs)
     _postproc_translate_options(a, postprocessor.TGBA, *args)
     if type(formula) == str:
         formula = parse_formula(formula)
-    return a.run(formula)
+    result = a.run(formula)
+    if xargs:
+        xargs.report_unused_options()
+    return result
 
 
 formula.translate = translate
@@ -725,7 +740,7 @@ _add_formula('contains')
 _add_formula('are_equivalent', 'equivalent_to')
 
 
-def postprocess(automaton, *args, formula=None):
+def postprocess(automaton, *args, formula=None, xargs=None):
     """Post process an automaton.
 
     This applies a number of simlification algorithms, depending on
@@ -751,16 +766,27 @@ def postprocess(automaton, *args, formula=None):
     If a formula denoted by this automaton is known, pass it to as the
     optional `formula` argument; it can help some algorithms by
     providing an easy way to complement the automaton.
-    """
-    p = postprocessor()
+
+    Additional options can be supplied using a `spot.option_map`, or a
+    string (that will be converted to `spot.option_map`), as the `xargs`
+    argument.  This is similar to the `-x` option of command-line tools;
+    so check out the spot-x(7) man page for details.
+"""
+    if type(xargs) is str:
+        xargs = option_map(xargs)
+    p = postprocessor(xargs)
     if type(automaton) == str:
         automaton = globals()['automaton'](automaton)
     _postproc_translate_options(p, postprocessor.Generic, *args)
-    return p.run(automaton, formula)
+    result = p.run(automaton, formula)
+    if xargs:
+        xargs.report_unused_options()
+    return result
 
 
 twa.postprocess = postprocess
 
+
 # Wrap C++-functions into lambdas so that they get converted into
 # instance methods (i.e., self passed as first argument
 # automatically), because only user-defined functions are converted as
@@ -1108,6 +1134,22 @@ formula.show_mp_hierarchy = show_mp_hierarchy
 
 @_extend(twa_word)
 class twa_word:
+    def _repr_latex_(self):
+        bd = self.get_dict()
+        res = '$'
+        for idx, letter in enumerate(self.prefix):
+            if idx:
+                res += '; '
+            res += bdd_to_formula(letter, bd).to_str('j')
+        if len(res) > 1:
+            res += '; ';
+        res += '\\mathsf{cycle}\\{';
+        for idx, letter in enumerate(self.cycle):
+            if idx:
+                res += '; '
+            res += bdd_to_formula(letter, bd).to_str('j')
+        return res + '\\}$'
+
     def as_svg(self):
         """
         Build an SVG picture representing the word as a collection of
