@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2016-2017 Laboratoire de Recherche et Développement
+// Copyright (C) 2016-2018 Laboratoire de Recherche et Développement
 // de l'Epita (LRDE).
 //
 // This file is part of Spot, a model checking library.
@@ -17,6 +17,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/twaalgos/couvreurnew.hh>
 
 #include <spot/twa/twa.hh>
@@ -263,7 +264,7 @@ namespace spot
     // A simple struct representing an SCC.
     struct scc
     {
-      scc(int i): index(i), condition(0U) {}
+      scc(int i): index(i), condition({}) {}
 
       int index;
       acc_cond::mark_t condition;
@@ -423,7 +424,7 @@ namespace spot
                 acc_cond::mark_t less_acc =
                   acc_to_traverse - st.acc;
                 if (less_acc != acc_to_traverse
-                    || (acc_to_traverse == 0U
+                    || (!acc_to_traverse
                         && T::from_state(ecs->aut, s) == ecs->cycle_seed))
                   {
                     acc_to_traverse = less_acc;
@@ -436,7 +437,7 @@ namespace spot
             substart = b.search(substart, run_->cycle);
             assert(substart);
           }
-        while (acc_to_traverse != 0U || substart != cycle_seed);
+        while (acc_to_traverse || substart != cycle_seed);
       }
     };
 
@@ -690,7 +691,7 @@ namespace spot
           ecs_->h[init] = 1;
           ecs_->root.push(1);
           if (strength == STRONG)
-            arc.push(0U);
+            arc.push({});
           auto iter = T::succ(ecs_->aut, init);
           todo.emplace(init, iter);
           live.emplace_back(init);
