@@ -1,5 +1,5 @@
 // -*- coding: utf-8 -*-
-// Copyright (C) 2008-2017 Laboratoire de Recherche et Développement
+// Copyright (C) 2008-2018 Laboratoire de Recherche et Développement
 // de l'Epita (LRDE).
 // Copyright (C) 2003-2006 Laboratoire d'Informatique de Paris 6
 // (LIP6), département Systèmes Répartis Coopératifs (SRC), Université
@@ -20,6 +20,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+#include "config.h"
 #include <spot/misc/hash.hh>
 #include <spot/misc/bddlt.hh>
 #include <spot/misc/minato.hh>
@@ -27,7 +28,6 @@
 #include <spot/tl/print.hh>
 #include <spot/tl/apcollect.hh>
 #include <spot/tl/mark.hh>
-#include <spot/tl/print.hh>
 #include <cassert>
 #include <memory>
 #include <utility>
@@ -35,7 +35,6 @@
 #include <spot/twaalgos/ltl2tgba_fm.hh>
 #include <spot/twa/bddprint.hh>
 #include <spot/twaalgos/sccinfo.hh>
-//#include "twaalgos/dot.hh"
 
 namespace spot
 {
@@ -237,7 +236,7 @@ namespace spot
       {
         bdd o = a;
         if (a == bddtrue)
-          return 0U;
+          return {};
         assert(a != bddfalse);
         std::vector<unsigned> t;
         do
@@ -1927,8 +1926,14 @@ namespace spot
     twa_graph_ptr a = make_twa_graph(dict);
     auto namer = a->create_namer<formula>();
 
-    translate_dict d(a, s, exprop, f2.is_syntactic_persistence(),
-                     unambiguous);
+    // Translating syntactic persistence will give a weak automaton, unless
+    // the unambiguous option is used.  In the "unambiguous" case, formulas
+    // such as "FGa | FGb" (note: not "F(Ga | Gb)") will introduce terms like
+    // "FGb&GF!a" that are not syntactic persistence.
+    bool will_be_weak = (unambiguous
+                         ? f2.is_syntactic_obligation()
+                         : f2.is_syntactic_persistence());
+    translate_dict d(a, s, exprop, will_be_weak, unambiguous);
 
     // Compute the set of all promises that can possibly occur inside
     // the formula.  These are the right-hand sides of U or F
@@ -2193,8 +2198,10 @@ namespace spot
 
     acc.set_generalized_buchi();
 
-    if (f2.is_syntactic_persistence())
-      a->prop_inherently_weak(true);
+    // The unambiguous option can introduce sub-terms that are not
+    // persistence, hence the resulting automaton might not be weak.
+    if (will_be_weak)
+      a->prop_weak(true);
     if (f2.is_syntactic_stutter_invariant())
       a->prop_stutter_invariant(true);
     if (orig_f.is_syntactic_guarantee())
